diff --git a/Build-Solution.ps1 b/Build-Solution.ps1
index 5b9f7d41..d97c0acb 100644
--- a/Build-Solution.ps1
+++ b/Build-Solution.ps1
@@ -12,6 +12,6 @@ param(
)
$scriptPath = Split-Path $MyInvocation.MyCommand.Path
-$projFile = join-path $scriptPath Octopi.msbuild
+$projFile = join-path $scriptPath Octokit.msbuild
& "$(get-content env:windir)\Microsoft.NET\Framework\v4.0.30319\MSBuild.exe" $projFile /t:$build /p:Configuration=$config /verbosity:$MSBuildVerbosity
diff --git a/CONTRIBUTING.md b/CONTRIBUTING.md
index 8faefa15..ba8cb123 100644
--- a/CONTRIBUTING.md
+++ b/CONTRIBUTING.md
@@ -1,10 +1,10 @@
# How to Contribute
-We love Pull Requests! Your contributions help make Octopi great.
+We love Pull Requests! Your contributions help make Octokit great.
## Getting Started
-So you want to contribute to Octopi. Great! Contributions take many forms from
+So you want to contribute to Octokit. Great! Contributions take many forms from
submitting issues, writing docs, to making code changes. We welcome it all.
But first things first...
@@ -16,7 +16,7 @@ But first things first...
* Fork the repository on GitHub by clicking on the "Clone in Windows" button or
run the following command in a git shell.
```
-git clone git@github.com:github/Octopi.git
+git clone git@github.com:github/Octokit.net.git Octokit
```
* Make sure the project builds and all tests pass on your machine by running
the `build.cmd` script (this calls a PowerShell script, `Build-Solution.ps1`).
diff --git a/CustomDictionary.xml b/CustomDictionary.xml
index 4e9b0fbf..a0afa4be 100644
--- a/CustomDictionary.xml
+++ b/CustomDictionary.xml
@@ -6,7 +6,7 @@
Git
Gists
Hireable
- Octopi
+ Octokit
OAuth
Poco
Ssh
diff --git a/Octopi.Reactive/Clients/ObservableAuthorizationsClient.cs b/Octokit.Reactive/Clients/ObservableAuthorizationsClient.cs
similarity index 97%
rename from Octopi.Reactive/Clients/ObservableAuthorizationsClient.cs
rename to Octokit.Reactive/Clients/ObservableAuthorizationsClient.cs
index fe2d7271..62589d8d 100644
--- a/Octopi.Reactive/Clients/ObservableAuthorizationsClient.cs
+++ b/Octokit.Reactive/Clients/ObservableAuthorizationsClient.cs
@@ -3,7 +3,7 @@ using System.Collections.Generic;
using System.Reactive;
using System.Reactive.Threading.Tasks;
-namespace Octopi.Reactive.Clients
+namespace Octokit.Reactive.Clients
{
public class ObservableAuthorizationsClient : IObservableAuthorizationsClient
{
diff --git a/Octopi.Reactive/Clients/ObservableAutoCompleteClient.cs b/Octokit.Reactive/Clients/ObservableAutoCompleteClient.cs
similarity index 94%
rename from Octopi.Reactive/Clients/ObservableAutoCompleteClient.cs
rename to Octokit.Reactive/Clients/ObservableAutoCompleteClient.cs
index 913455c2..0cf25d9d 100644
--- a/Octopi.Reactive/Clients/ObservableAutoCompleteClient.cs
+++ b/Octokit.Reactive/Clients/ObservableAutoCompleteClient.cs
@@ -2,7 +2,7 @@
using System.Collections.Generic;
using System.Reactive.Threading.Tasks;
-namespace Octopi.Reactive.Clients
+namespace Octokit.Reactive.Clients
{
public class ObservableAutoCompleteClient : IObservableAutoCompleteClient
{
diff --git a/Octopi.Reactive/Clients/ObservableOrganizationsClient.cs b/Octokit.Reactive/Clients/ObservableOrganizationsClient.cs
similarity index 96%
rename from Octopi.Reactive/Clients/ObservableOrganizationsClient.cs
rename to Octokit.Reactive/Clients/ObservableOrganizationsClient.cs
index 4fd248cf..a556b06f 100644
--- a/Octopi.Reactive/Clients/ObservableOrganizationsClient.cs
+++ b/Octokit.Reactive/Clients/ObservableOrganizationsClient.cs
@@ -2,7 +2,7 @@
using System.Collections.Generic;
using System.Reactive.Threading.Tasks;
-namespace Octopi.Reactive.Clients
+namespace Octokit.Reactive.Clients
{
public class ObservableOrganizationsClient : IObservableOrganizationsClient
{
diff --git a/Octopi.Reactive/Clients/ObservableRepositoriesClient.cs b/Octokit.Reactive/Clients/ObservableRepositoriesClient.cs
similarity index 97%
rename from Octopi.Reactive/Clients/ObservableRepositoriesClient.cs
rename to Octokit.Reactive/Clients/ObservableRepositoriesClient.cs
index 863dbace..5463f789 100644
--- a/Octopi.Reactive/Clients/ObservableRepositoriesClient.cs
+++ b/Octokit.Reactive/Clients/ObservableRepositoriesClient.cs
@@ -2,7 +2,7 @@
using System.Collections.Generic;
using System.Reactive.Threading.Tasks;
-namespace Octopi.Reactive.Clients
+namespace Octokit.Reactive.Clients
{
public class ObservableRepositoriesClient : IObservableRepositoriesClient
{
diff --git a/Octopi.Reactive/Clients/ObservableSshKeysClient.cs b/Octokit.Reactive/Clients/ObservableSshKeysClient.cs
similarity index 97%
rename from Octopi.Reactive/Clients/ObservableSshKeysClient.cs
rename to Octokit.Reactive/Clients/ObservableSshKeysClient.cs
index 4692bd51..3ca33f80 100644
--- a/Octopi.Reactive/Clients/ObservableSshKeysClient.cs
+++ b/Octokit.Reactive/Clients/ObservableSshKeysClient.cs
@@ -3,7 +3,7 @@ using System.Collections.Generic;
using System.Reactive;
using System.Reactive.Threading.Tasks;
-namespace Octopi.Reactive.Clients
+namespace Octokit.Reactive.Clients
{
public class ObservableSshKeysClient : IObservableSshKeysClient
{
diff --git a/Octopi.Reactive/Clients/ObservableUsersClient.cs b/Octokit.Reactive/Clients/ObservableUsersClient.cs
similarity index 95%
rename from Octopi.Reactive/Clients/ObservableUsersClient.cs
rename to Octokit.Reactive/Clients/ObservableUsersClient.cs
index 636a9f83..3325ca2b 100644
--- a/Octopi.Reactive/Clients/ObservableUsersClient.cs
+++ b/Octokit.Reactive/Clients/ObservableUsersClient.cs
@@ -1,7 +1,7 @@
using System;
using System.Reactive.Threading.Tasks;
-namespace Octopi.Reactive.Clients
+namespace Octokit.Reactive.Clients
{
public class ObservableUsersClient : IObservableUsersClient
{
diff --git a/Octopi.Reactive/IObservableAuthorizationsClient.cs b/Octokit.Reactive/IObservableAuthorizationsClient.cs
similarity index 96%
rename from Octopi.Reactive/IObservableAuthorizationsClient.cs
rename to Octokit.Reactive/IObservableAuthorizationsClient.cs
index 632aec4f..b41f1d82 100644
--- a/Octopi.Reactive/IObservableAuthorizationsClient.cs
+++ b/Octokit.Reactive/IObservableAuthorizationsClient.cs
@@ -3,7 +3,7 @@ using System.Collections.Generic;
using System.Diagnostics.CodeAnalysis;
using System.Reactive;
-namespace Octopi.Reactive
+namespace Octokit.Reactive
{
public interface IObservableAuthorizationsClient
{
diff --git a/Octopi.Reactive/IObservableAutoCompleteClient.cs b/Octokit.Reactive/IObservableAutoCompleteClient.cs
similarity index 93%
rename from Octopi.Reactive/IObservableAutoCompleteClient.cs
rename to Octokit.Reactive/IObservableAutoCompleteClient.cs
index e5170b0b..415c5989 100644
--- a/Octopi.Reactive/IObservableAutoCompleteClient.cs
+++ b/Octokit.Reactive/IObservableAutoCompleteClient.cs
@@ -2,7 +2,7 @@
using System.Collections.Generic;
using System.Diagnostics.CodeAnalysis;
-namespace Octopi.Reactive
+namespace Octokit.Reactive
{
public interface IObservableAutoCompleteClient
{
diff --git a/Octopi.Reactive/IObservableGitHubClient.cs b/Octokit.Reactive/IObservableGitHubClient.cs
similarity index 92%
rename from Octopi.Reactive/IObservableGitHubClient.cs
rename to Octokit.Reactive/IObservableGitHubClient.cs
index aa1808ca..374e541d 100644
--- a/Octopi.Reactive/IObservableGitHubClient.cs
+++ b/Octokit.Reactive/IObservableGitHubClient.cs
@@ -1,4 +1,4 @@
-namespace Octopi.Reactive
+namespace Octokit.Reactive
{
public interface IObservableGitHubClient
{
diff --git a/Octopi.Reactive/IObservableOrganizationsClient.cs b/Octokit.Reactive/IObservableOrganizationsClient.cs
similarity index 97%
rename from Octopi.Reactive/IObservableOrganizationsClient.cs
rename to Octokit.Reactive/IObservableOrganizationsClient.cs
index 90713afb..748fac90 100644
--- a/Octopi.Reactive/IObservableOrganizationsClient.cs
+++ b/Octokit.Reactive/IObservableOrganizationsClient.cs
@@ -2,7 +2,7 @@
using System.Collections.Generic;
using System.Diagnostics.CodeAnalysis;
-namespace Octopi.Reactive
+namespace Octokit.Reactive
{
public interface IObservableOrganizationsClient
{
diff --git a/Octopi.Reactive/IObservableRepositoriesClient.cs b/Octokit.Reactive/IObservableRepositoriesClient.cs
similarity index 99%
rename from Octopi.Reactive/IObservableRepositoriesClient.cs
rename to Octokit.Reactive/IObservableRepositoriesClient.cs
index d6f549ab..ea3a1b8e 100644
--- a/Octopi.Reactive/IObservableRepositoriesClient.cs
+++ b/Octokit.Reactive/IObservableRepositoriesClient.cs
@@ -2,7 +2,7 @@
using System.Collections.Generic;
using System.Diagnostics.CodeAnalysis;
-namespace Octopi.Reactive
+namespace Octokit.Reactive
{
public interface IObservableRepositoriesClient
{
diff --git a/Octopi.Reactive/IObservableSshKeysClient.cs b/Octokit.Reactive/IObservableSshKeysClient.cs
similarity index 98%
rename from Octopi.Reactive/IObservableSshKeysClient.cs
rename to Octokit.Reactive/IObservableSshKeysClient.cs
index 4a80fe46..9e01244c 100644
--- a/Octopi.Reactive/IObservableSshKeysClient.cs
+++ b/Octokit.Reactive/IObservableSshKeysClient.cs
@@ -3,7 +3,7 @@ using System.Collections.Generic;
using System.Diagnostics.CodeAnalysis;
using System.Reactive;
-namespace Octopi.Reactive
+namespace Octokit.Reactive
{
public interface IObservableSshKeysClient
{
diff --git a/Octopi.Reactive/IObservableUsersClient.cs b/Octokit.Reactive/IObservableUsersClient.cs
similarity index 97%
rename from Octopi.Reactive/IObservableUsersClient.cs
rename to Octokit.Reactive/IObservableUsersClient.cs
index 58097898..0372e596 100644
--- a/Octopi.Reactive/IObservableUsersClient.cs
+++ b/Octokit.Reactive/IObservableUsersClient.cs
@@ -3,7 +3,7 @@ using System.Collections.Generic;
using System.Diagnostics.CodeAnalysis;
using System.Threading.Tasks;
-namespace Octopi.Reactive
+namespace Octokit.Reactive
{
public interface IObservableUsersClient
{
diff --git a/Octopi.Reactive/ObservableExtensions.cs b/Octokit.Reactive/ObservableExtensions.cs
similarity index 93%
rename from Octopi.Reactive/ObservableExtensions.cs
rename to Octokit.Reactive/ObservableExtensions.cs
index 9288cc39..45a3bd13 100644
--- a/Octopi.Reactive/ObservableExtensions.cs
+++ b/Octokit.Reactive/ObservableExtensions.cs
@@ -2,7 +2,7 @@
using System.Reactive.Linq;
using System.Reactive.Threading.Tasks;
-namespace Octopi.Reactive
+namespace Octokit.Reactive
{
public static class ObservableExtensions
{
diff --git a/Octopi.Reactive/ObservableGitHubClient.cs b/Octokit.Reactive/ObservableGitHubClient.cs
similarity index 95%
rename from Octopi.Reactive/ObservableGitHubClient.cs
rename to Octokit.Reactive/ObservableGitHubClient.cs
index 58ab5edb..aa314b5f 100644
--- a/Octopi.Reactive/ObservableGitHubClient.cs
+++ b/Octokit.Reactive/ObservableGitHubClient.cs
@@ -1,6 +1,6 @@
-using Octopi.Reactive.Clients;
+using Octokit.Reactive.Clients;
-namespace Octopi.Reactive
+namespace Octokit.Reactive
{
public class ObservableGitHubClient : IObservableGitHubClient
{
diff --git a/Octopi.Reactive/Octopi.Reactive.csproj b/Octokit.Reactive/Octokit.Reactive.csproj
similarity index 90%
rename from Octopi.Reactive/Octopi.Reactive.csproj
rename to Octokit.Reactive/Octokit.Reactive.csproj
index 47aec554..bd5a1969 100644
--- a/Octopi.Reactive/Octopi.Reactive.csproj
+++ b/Octokit.Reactive/Octokit.Reactive.csproj
@@ -7,8 +7,8 @@
{674B69B8-0780-4D54-AE2B-C15821FA51CB}
Library
Properties
- Octopi.Reactive
- Octopi.Reactive
+ Octokit.Reactive
+ Octokit.Reactive
v4.5
512
@@ -20,6 +20,9 @@
DEBUG;TRACE
prompt
4
+ true
+ true
+ ..\Octokit.ruleset
pdbonly
@@ -51,7 +54,7 @@
-
+
Helpers\Ensure.cs
@@ -72,9 +75,9 @@
-
+
{08dd4305-7787-4823-a53f-4d0f725a07f3}
- Octopi
+ Octokit
diff --git a/Octopi.Reactive/Properties/AssemblyInfo.cs b/Octokit.Reactive/Properties/AssemblyInfo.cs
similarity index 93%
rename from Octopi.Reactive/Properties/AssemblyInfo.cs
rename to Octokit.Reactive/Properties/AssemblyInfo.cs
index ad598af2..1d92c771 100644
--- a/Octopi.Reactive/Properties/AssemblyInfo.cs
+++ b/Octokit.Reactive/Properties/AssemblyInfo.cs
@@ -5,11 +5,11 @@ using System.Runtime.InteropServices;
// General Information about an assembly is controlled through the following
// set of attributes. Change these attribute values to modify the information
// associated with an assembly.
-[assembly: AssemblyTitle("Octopi.Reactive")]
+[assembly: AssemblyTitle("Octokit.Reactive")]
[assembly: AssemblyDescription("")]
[assembly: AssemblyConfiguration("")]
[assembly: AssemblyCompany("")]
-[assembly: AssemblyProduct("Octopi.Reactive")]
+[assembly: AssemblyProduct("Octokit.Reactive")]
[assembly: AssemblyCopyright("Copyright © 2013")]
[assembly: AssemblyTrademark("")]
[assembly: AssemblyCulture("")]
diff --git a/Octopi.Reactive/packages.config b/Octokit.Reactive/packages.config
similarity index 100%
rename from Octopi.Reactive/packages.config
rename to Octokit.Reactive/packages.config
diff --git a/Octopi.Tests.Integration/AutoCompleteClientTests.cs b/Octokit.Tests.Integration/AutoCompleteClientTests.cs
similarity index 91%
rename from Octopi.Tests.Integration/AutoCompleteClientTests.cs
rename to Octokit.Tests.Integration/AutoCompleteClientTests.cs
index 0baa22ac..9b32b1ab 100644
--- a/Octopi.Tests.Integration/AutoCompleteClientTests.cs
+++ b/Octokit.Tests.Integration/AutoCompleteClientTests.cs
@@ -1,9 +1,9 @@
using System.Threading.Tasks;
using FluentAssertions;
-using Octopi.Http;
+using Octokit.Http;
using Xunit;
-namespace Octopi.Tests.Integration
+namespace Octokit.Tests.Integration
{
public class AutoCompleteClientTests
{
diff --git a/Octopi.Tests.Integration/Octopi.Tests.Integration.csproj b/Octokit.Tests.Integration/Octokit.Tests.Integration.csproj
similarity index 91%
rename from Octopi.Tests.Integration/Octopi.Tests.Integration.csproj
rename to Octokit.Tests.Integration/Octokit.Tests.Integration.csproj
index 134804e8..68b7cf4f 100644
--- a/Octopi.Tests.Integration/Octopi.Tests.Integration.csproj
+++ b/Octokit.Tests.Integration/Octokit.Tests.Integration.csproj
@@ -7,8 +7,8 @@
{01687D54-1D87-4562-A721-C57F1C94052C}
Library
Properties
- Octopi.Tests.Integration
- Octopi.Tests.Integration
+ Octokit.Tests.Integration
+ Octokit.Tests.Integration
v4.5
512
@@ -55,13 +55,13 @@
-
+
{149448d4-c2f2-4df9-86bd-03e3272f093b}
- Octopi.Tests
+ Octokit.Tests
-
+
{08dd4305-7787-4823-a53f-4d0f725a07f3}
- Octopi
+ Octokit
diff --git a/Octopi.Tests.Integration/Properties/AssemblyInfo.cs b/Octokit.Tests.Integration/Properties/AssemblyInfo.cs
similarity index 92%
rename from Octopi.Tests.Integration/Properties/AssemblyInfo.cs
rename to Octokit.Tests.Integration/Properties/AssemblyInfo.cs
index 9f785f22..7d2624d8 100644
--- a/Octopi.Tests.Integration/Properties/AssemblyInfo.cs
+++ b/Octokit.Tests.Integration/Properties/AssemblyInfo.cs
@@ -5,11 +5,11 @@ using System.Runtime.InteropServices;
// set of attributes. Change these attribute values to modify the information
// associated with an assembly.
-[assembly: AssemblyTitle("Octopi.Tests.Integration")]
+[assembly: AssemblyTitle("Octokit.Tests.Integration")]
[assembly: AssemblyDescription("")]
[assembly: AssemblyConfiguration("")]
[assembly: AssemblyCompany("Microsoft")]
-[assembly: AssemblyProduct("Octopi.Tests.Integration")]
+[assembly: AssemblyProduct("Octokit.Tests.Integration")]
[assembly: AssemblyCopyright("Copyright © Microsoft 2012")]
[assembly: AssemblyTrademark("")]
[assembly: AssemblyCulture("")]
diff --git a/Octopi.Tests.Integration/UsersClientTests.cs b/Octokit.Tests.Integration/UsersClientTests.cs
similarity index 96%
rename from Octopi.Tests.Integration/UsersClientTests.cs
rename to Octokit.Tests.Integration/UsersClientTests.cs
index ea6ec238..ec441011 100644
--- a/Octopi.Tests.Integration/UsersClientTests.cs
+++ b/Octokit.Tests.Integration/UsersClientTests.cs
@@ -3,11 +3,11 @@ using System.Net;
using System.Net.Http;
using System.Threading.Tasks;
using FluentAssertions;
-using Octopi.Http;
-using Octopi.Tests.Helpers;
+using Octokit.Http;
+using Octokit.Tests.Helpers;
using Xunit;
-namespace Octopi.Tests.Integration
+namespace Octokit.Tests.Integration
{
public class UsersClientTests
{
diff --git a/Octopi.Tests.Integration/packages.config b/Octokit.Tests.Integration/packages.config
similarity index 100%
rename from Octopi.Tests.Integration/packages.config
rename to Octokit.Tests.Integration/packages.config
diff --git a/Octopi.Tests/Authentication/BasicAuthenticatorTests.cs b/Octokit.Tests/Authentication/BasicAuthenticatorTests.cs
similarity index 94%
rename from Octopi.Tests/Authentication/BasicAuthenticatorTests.cs
rename to Octokit.Tests/Authentication/BasicAuthenticatorTests.cs
index 7333d709..10df18f2 100644
--- a/Octopi.Tests/Authentication/BasicAuthenticatorTests.cs
+++ b/Octokit.Tests/Authentication/BasicAuthenticatorTests.cs
@@ -1,10 +1,10 @@
using System;
using FluentAssertions;
-using Octopi.Authentication;
-using Octopi.Http;
+using Octokit.Authentication;
+using Octokit.Http;
using Xunit;
-namespace Octopi.Tests
+namespace Octokit.Tests
{
public class BasicAuthenticatorTests
{
diff --git a/Octopi.Tests/Authentication/CredentialsTests.cs b/Octokit.Tests/Authentication/CredentialsTests.cs
similarity index 97%
rename from Octopi.Tests/Authentication/CredentialsTests.cs
rename to Octokit.Tests/Authentication/CredentialsTests.cs
index b097c81d..a83d4069 100644
--- a/Octopi.Tests/Authentication/CredentialsTests.cs
+++ b/Octokit.Tests/Authentication/CredentialsTests.cs
@@ -1,9 +1,9 @@
using System;
using FluentAssertions;
-using Octopi.Http;
+using Octokit.Http;
using Xunit;
-namespace Octopi.Tests.Authentication
+namespace Octokit.Tests.Authentication
{
public class CredentialsTests
{
diff --git a/Octopi.Tests/Authentication/TokenAuthenticatorTests.cs b/Octokit.Tests/Authentication/TokenAuthenticatorTests.cs
similarity index 95%
rename from Octopi.Tests/Authentication/TokenAuthenticatorTests.cs
rename to Octokit.Tests/Authentication/TokenAuthenticatorTests.cs
index 565e43c9..a1579082 100644
--- a/Octopi.Tests/Authentication/TokenAuthenticatorTests.cs
+++ b/Octokit.Tests/Authentication/TokenAuthenticatorTests.cs
@@ -1,11 +1,11 @@
using System;
using FluentAssertions;
using NSubstitute;
-using Octopi.Authentication;
-using Octopi.Http;
+using Octokit.Authentication;
+using Octokit.Http;
using Xunit;
-namespace Octopi.Tests
+namespace Octokit.Tests
{
public class TokenAuthenticatorTests
{
diff --git a/Octopi.Tests/Clients/AuthorizationsClientTests.cs b/Octokit.Tests/Clients/AuthorizationsClientTests.cs
similarity index 97%
rename from Octopi.Tests/Clients/AuthorizationsClientTests.cs
rename to Octokit.Tests/Clients/AuthorizationsClientTests.cs
index 6c31459c..ca9d90ef 100644
--- a/Octopi.Tests/Clients/AuthorizationsClientTests.cs
+++ b/Octokit.Tests/Clients/AuthorizationsClientTests.cs
@@ -1,10 +1,10 @@
using System;
using NSubstitute;
-using Octopi.Clients;
-using Octopi.Http;
+using Octokit.Clients;
+using Octokit.Http;
using Xunit;
-namespace Octopi.Tests.Clients
+namespace Octokit.Tests.Clients
{
///
/// Client tests mostly just need to make sure they call the IApiConnection with the correct
diff --git a/Octopi.Tests/Clients/AutoCompleteClientTests.cs b/Octokit.Tests/Clients/AutoCompleteClientTests.cs
similarity index 95%
rename from Octopi.Tests/Clients/AutoCompleteClientTests.cs
rename to Octokit.Tests/Clients/AutoCompleteClientTests.cs
index c761842f..4baaa94d 100644
--- a/Octopi.Tests/Clients/AutoCompleteClientTests.cs
+++ b/Octokit.Tests/Clients/AutoCompleteClientTests.cs
@@ -3,11 +3,11 @@ using System.Collections.Generic;
using System.Threading.Tasks;
using FluentAssertions;
using NSubstitute;
-using Octopi.Clients;
-using Octopi.Http;
+using Octokit.Clients;
+using Octokit.Http;
using Xunit;
-namespace Octopi.Tests.Clients
+namespace Octokit.Tests.Clients
{
public class AutoCompleteClientTests
{
diff --git a/Octopi.Tests/Clients/OrganizationsClientTests.cs b/Octokit.Tests/Clients/OrganizationsClientTests.cs
similarity index 96%
rename from Octopi.Tests/Clients/OrganizationsClientTests.cs
rename to Octokit.Tests/Clients/OrganizationsClientTests.cs
index 665b4bcc..cf7ff268 100644
--- a/Octopi.Tests/Clients/OrganizationsClientTests.cs
+++ b/Octokit.Tests/Clients/OrganizationsClientTests.cs
@@ -1,12 +1,12 @@
using System;
using System.Threading.Tasks;
using NSubstitute;
-using Octopi.Clients;
-using Octopi.Http;
-using Octopi.Tests.Helpers;
+using Octokit.Clients;
+using Octokit.Http;
+using Octokit.Tests.Helpers;
using Xunit;
-namespace Octopi.Tests.Clients
+namespace Octokit.Tests.Clients
{
///
/// Client tests mostly just need to make sure they call the IApiConnection with the correct
diff --git a/Octopi.Tests/Clients/RepositoriesClientTests.cs b/Octokit.Tests/Clients/RepositoriesClientTests.cs
similarity index 98%
rename from Octopi.Tests/Clients/RepositoriesClientTests.cs
rename to Octokit.Tests/Clients/RepositoriesClientTests.cs
index 638812bb..4abede76 100644
--- a/Octopi.Tests/Clients/RepositoriesClientTests.cs
+++ b/Octokit.Tests/Clients/RepositoriesClientTests.cs
@@ -3,12 +3,12 @@ using System.Text;
using System.Threading.Tasks;
using FluentAssertions;
using NSubstitute;
-using Octopi.Clients;
-using Octopi.Http;
-using Octopi.Tests.Helpers;
+using Octokit.Clients;
+using Octokit.Http;
+using Octokit.Tests.Helpers;
using Xunit;
-namespace Octopi.Tests.Clients
+namespace Octokit.Tests.Clients
{
///
/// Client tests mostly just need to make sure they call the IApiConnection with the correct
diff --git a/Octopi.Tests/Clients/SshKeysClientTests.cs b/Octokit.Tests/Clients/SshKeysClientTests.cs
similarity index 97%
rename from Octopi.Tests/Clients/SshKeysClientTests.cs
rename to Octokit.Tests/Clients/SshKeysClientTests.cs
index 4f9808db..8de2d0d0 100644
--- a/Octopi.Tests/Clients/SshKeysClientTests.cs
+++ b/Octokit.Tests/Clients/SshKeysClientTests.cs
@@ -1,12 +1,12 @@
using System;
using System.Threading.Tasks;
using NSubstitute;
-using Octopi.Clients;
-using Octopi.Http;
-using Octopi.Tests.Helpers;
+using Octokit.Clients;
+using Octokit.Http;
+using Octokit.Tests.Helpers;
using Xunit;
-namespace Octopi.Tests.Clients
+namespace Octokit.Tests.Clients
{
///
/// Client tests mostly just need to make sure they call the IApiConnection with the correct
diff --git a/Octopi.Tests/Clients/UsersClientTests.cs b/Octokit.Tests/Clients/UsersClientTests.cs
similarity index 96%
rename from Octopi.Tests/Clients/UsersClientTests.cs
rename to Octokit.Tests/Clients/UsersClientTests.cs
index ff16a034..ea4f24a5 100644
--- a/Octopi.Tests/Clients/UsersClientTests.cs
+++ b/Octokit.Tests/Clients/UsersClientTests.cs
@@ -1,12 +1,12 @@
using System;
using System.Threading.Tasks;
using NSubstitute;
-using Octopi.Clients;
-using Octopi.Http;
-using Octopi.Tests.Helpers;
+using Octokit.Clients;
+using Octokit.Http;
+using Octokit.Tests.Helpers;
using Xunit;
-namespace Octopi.Tests.Clients
+namespace Octokit.Tests.Clients
{
///
/// Client tests mostly just need to make sure they call the IApiConnection with the correct
diff --git a/Octopi.Tests/Fixtures/EmbeddedResource.cs b/Octokit.Tests/Fixtures/EmbeddedResource.cs
similarity index 97%
rename from Octopi.Tests/Fixtures/EmbeddedResource.cs
rename to Octokit.Tests/Fixtures/EmbeddedResource.cs
index d99293d2..0e4accbc 100644
--- a/Octopi.Tests/Fixtures/EmbeddedResource.cs
+++ b/Octokit.Tests/Fixtures/EmbeddedResource.cs
@@ -2,7 +2,7 @@
using System.Reflection;
using System.Text;
-namespace Octopi.Tests
+namespace Octokit.Tests
{
///
/// Helper class for handling our embedded resources.
diff --git a/Octopi.Tests/Fixtures/Fixtures.cs b/Octokit.Tests/Fixtures/Fixtures.cs
similarity index 74%
rename from Octopi.Tests/Fixtures/Fixtures.cs
rename to Octokit.Tests/Fixtures/Fixtures.cs
index 62ce6af8..b9bdac72 100644
--- a/Octopi.Tests/Fixtures/Fixtures.cs
+++ b/Octokit.Tests/Fixtures/Fixtures.cs
@@ -1,23 +1,23 @@
-namespace Octopi.Tests
+namespace Octokit.Tests
{
public static class Fixtures
{
public static EmbeddedResource AuthorizationsJson =
- new EmbeddedResource(typeof(Fixtures).Assembly, "Octopi.Tests.Fixtures.authorizations.json");
+ new EmbeddedResource(typeof(Fixtures).Assembly, "Octokit.Tests.Fixtures.authorizations.json");
public static EmbeddedResource AuthorizationJson =
- new EmbeddedResource(typeof(Fixtures).Assembly, "Octopi.Tests.Fixtures.authorization.json");
+ new EmbeddedResource(typeof(Fixtures).Assembly, "Octokit.Tests.Fixtures.authorization.json");
public static EmbeddedResource UserJson =
- new EmbeddedResource(typeof(Fixtures).Assembly, "Octopi.Tests.Fixtures.user.json");
+ new EmbeddedResource(typeof(Fixtures).Assembly, "Octokit.Tests.Fixtures.user.json");
public static EmbeddedResource UserFullJson =
- new EmbeddedResource(typeof(Fixtures).Assembly, "Octopi.Tests.Fixtures.user_full.json");
+ new EmbeddedResource(typeof(Fixtures).Assembly, "Octokit.Tests.Fixtures.user_full.json");
public static EmbeddedResource RepositoryJson =
- new EmbeddedResource(typeof(Fixtures).Assembly, "Octopi.Tests.Fixtures.repository.json");
+ new EmbeddedResource(typeof(Fixtures).Assembly, "Octokit.Tests.Fixtures.repository.json");
public static EmbeddedResource RepositoriesJson =
- new EmbeddedResource(typeof(Fixtures).Assembly, "Octopi.Tests.Fixtures.repositories.json");
+ new EmbeddedResource(typeof(Fixtures).Assembly, "Octokit.Tests.Fixtures.repositories.json");
}
}
diff --git a/Octopi.Tests/Fixtures/authorization.json b/Octokit.Tests/Fixtures/authorization.json
similarity index 100%
rename from Octopi.Tests/Fixtures/authorization.json
rename to Octokit.Tests/Fixtures/authorization.json
diff --git a/Octopi.Tests/Fixtures/authorizations.json b/Octokit.Tests/Fixtures/authorizations.json
similarity index 100%
rename from Octopi.Tests/Fixtures/authorizations.json
rename to Octokit.Tests/Fixtures/authorizations.json
diff --git a/Octopi.Tests/Fixtures/repositories.json b/Octokit.Tests/Fixtures/repositories.json
similarity index 100%
rename from Octopi.Tests/Fixtures/repositories.json
rename to Octokit.Tests/Fixtures/repositories.json
diff --git a/Octopi.Tests/Fixtures/repository.json b/Octokit.Tests/Fixtures/repository.json
similarity index 100%
rename from Octopi.Tests/Fixtures/repository.json
rename to Octokit.Tests/Fixtures/repository.json
diff --git a/Octopi.Tests/Fixtures/user.json b/Octokit.Tests/Fixtures/user.json
similarity index 100%
rename from Octopi.Tests/Fixtures/user.json
rename to Octokit.Tests/Fixtures/user.json
diff --git a/Octopi.Tests/Fixtures/user_full.json b/Octokit.Tests/Fixtures/user_full.json
similarity index 100%
rename from Octopi.Tests/Fixtures/user_full.json
rename to Octokit.Tests/Fixtures/user_full.json
diff --git a/Octopi.Tests/GitHubClientTests.cs b/Octokit.Tests/GitHubClientTests.cs
similarity index 98%
rename from Octopi.Tests/GitHubClientTests.cs
rename to Octokit.Tests/GitHubClientTests.cs
index dd53a62a..05a5f8b2 100644
--- a/Octopi.Tests/GitHubClientTests.cs
+++ b/Octokit.Tests/GitHubClientTests.cs
@@ -1,10 +1,10 @@
using System;
using FluentAssertions;
using NSubstitute;
-using Octopi.Http;
+using Octokit.Http;
using Xunit;
-namespace Octopi.Tests
+namespace Octokit.Tests
{
public class GitHubClientTests
{
diff --git a/Octopi.Tests/Helpers/Arg.cs b/Octokit.Tests/Helpers/Arg.cs
similarity index 93%
rename from Octopi.Tests/Helpers/Arg.cs
rename to Octokit.Tests/Helpers/Arg.cs
index 0891c927..e14868aa 100644
--- a/Octopi.Tests/Helpers/Arg.cs
+++ b/Octokit.Tests/Helpers/Arg.cs
@@ -1,8 +1,8 @@
using System;
using NSubstitute;
-using Octopi.Http;
+using Octokit.Http;
-namespace Octopi.Tests
+namespace Octokit.Tests
{
internal class Args
{
diff --git a/Octopi.Tests/Helpers/AssertEx.cs b/Octokit.Tests/Helpers/AssertEx.cs
similarity index 95%
rename from Octopi.Tests/Helpers/AssertEx.cs
rename to Octokit.Tests/Helpers/AssertEx.cs
index b2da7348..cbb8d888 100644
--- a/Octopi.Tests/Helpers/AssertEx.cs
+++ b/Octokit.Tests/Helpers/AssertEx.cs
@@ -2,7 +2,7 @@
using System.Threading.Tasks;
using Xunit;
-namespace Octopi.Tests.Helpers
+namespace Octokit.Tests.Helpers
{
public static class AssertEx
{
diff --git a/Octopi.Tests/Helpers/StringExtensionsTests.cs b/Octokit.Tests/Helpers/StringExtensionsTests.cs
similarity index 97%
rename from Octopi.Tests/Helpers/StringExtensionsTests.cs
rename to Octokit.Tests/Helpers/StringExtensionsTests.cs
index 1da1c87a..f46fade9 100644
--- a/Octopi.Tests/Helpers/StringExtensionsTests.cs
+++ b/Octokit.Tests/Helpers/StringExtensionsTests.cs
@@ -3,7 +3,7 @@ using FluentAssertions;
using Xunit;
using Xunit.Extensions;
-namespace Octopi.Tests.Helpers
+namespace Octokit.Tests.Helpers
{
public class StringExtensionsTests
{
diff --git a/Octopi.Tests/Http/ApiConnectionTests.cs b/Octokit.Tests/Http/ApiConnectionTests.cs
similarity index 99%
rename from Octopi.Tests/Http/ApiConnectionTests.cs
rename to Octokit.Tests/Http/ApiConnectionTests.cs
index 9e944e9f..8bf90588 100644
--- a/Octopi.Tests/Http/ApiConnectionTests.cs
+++ b/Octokit.Tests/Http/ApiConnectionTests.cs
@@ -3,11 +3,11 @@ using System.Collections.Generic;
using System.Threading.Tasks;
using FluentAssertions;
using NSubstitute;
-using Octopi.Http;
-using Octopi.Tests.Helpers;
+using Octokit.Http;
+using Octokit.Tests.Helpers;
using Xunit;
-namespace Octopi.Tests.Http
+namespace Octokit.Tests.Http
{
public class ApiConnectionTests
{
diff --git a/Octopi.Tests/Http/ApiInfoParserTests.cs b/Octokit.Tests/Http/ApiInfoParserTests.cs
similarity index 99%
rename from Octopi.Tests/Http/ApiInfoParserTests.cs
rename to Octokit.Tests/Http/ApiInfoParserTests.cs
index c01aee46..69ed94ef 100644
--- a/Octopi.Tests/Http/ApiInfoParserTests.cs
+++ b/Octokit.Tests/Http/ApiInfoParserTests.cs
@@ -1,11 +1,11 @@
using System;
using System.Collections.Generic;
using FluentAssertions;
-using Octopi.Http;
+using Octokit.Http;
using Xunit;
using Xunit.Extensions;
-namespace Octopi.Tests
+namespace Octokit.Tests
{
public class ApiInfoParserTests
{
diff --git a/Octopi.Tests/Http/ConnectionTests.cs b/Octokit.Tests/Http/ConnectionTests.cs
similarity index 99%
rename from Octopi.Tests/Http/ConnectionTests.cs
rename to Octokit.Tests/Http/ConnectionTests.cs
index f42ba0ed..44549957 100644
--- a/Octopi.Tests/Http/ConnectionTests.cs
+++ b/Octokit.Tests/Http/ConnectionTests.cs
@@ -4,10 +4,10 @@ using System.Net.Http;
using System.Threading.Tasks;
using FluentAssertions;
using NSubstitute;
-using Octopi.Http;
+using Octokit.Http;
using Xunit;
-namespace Octopi.Tests.Http
+namespace Octokit.Tests.Http
{
public class ConnectionTests
{
diff --git a/Octopi.Tests/Http/HttpClientAdapterTests.cs b/Octokit.Tests/Http/HttpClientAdapterTests.cs
similarity index 98%
rename from Octopi.Tests/Http/HttpClientAdapterTests.cs
rename to Octokit.Tests/Http/HttpClientAdapterTests.cs
index 15ad9c44..83f2090d 100644
--- a/Octopi.Tests/Http/HttpClientAdapterTests.cs
+++ b/Octokit.Tests/Http/HttpClientAdapterTests.cs
@@ -5,10 +5,10 @@ using System.Net.Http;
using System.Text;
using System.Threading.Tasks;
using FluentAssertions;
-using Octopi.Http;
+using Octokit.Http;
using Xunit;
-namespace Octopi.Tests.Http
+namespace Octokit.Tests.Http
{
public class HttpClientAdapterTests
{
diff --git a/Octopi.Tests/Http/JsonHttpPipelineTests.cs b/Octokit.Tests/Http/JsonHttpPipelineTests.cs
similarity index 97%
rename from Octopi.Tests/Http/JsonHttpPipelineTests.cs
rename to Octokit.Tests/Http/JsonHttpPipelineTests.cs
index fdb5084d..3709b191 100644
--- a/Octopi.Tests/Http/JsonHttpPipelineTests.cs
+++ b/Octokit.Tests/Http/JsonHttpPipelineTests.cs
@@ -1,9 +1,9 @@
using System;
using FluentAssertions;
-using Octopi.Http;
+using Octokit.Http;
using Xunit;
-namespace Octopi.Tests.Http
+namespace Octokit.Tests.Http
{
public class JsonHttpPipelineTests
{
diff --git a/Octopi.Tests/Http/RequestTests.cs b/Octokit.Tests/Http/RequestTests.cs
similarity index 87%
rename from Octopi.Tests/Http/RequestTests.cs
rename to Octokit.Tests/Http/RequestTests.cs
index 14e8317f..de4551ca 100644
--- a/Octopi.Tests/Http/RequestTests.cs
+++ b/Octokit.Tests/Http/RequestTests.cs
@@ -1,8 +1,8 @@
using FluentAssertions;
-using Octopi.Http;
+using Octokit.Http;
using Xunit;
-namespace Octopi.Tests.Http
+namespace Octokit.Tests.Http
{
public class RequestTests
{
diff --git a/Octopi.Tests/Http/ResponseTests.cs b/Octokit.Tests/Http/ResponseTests.cs
similarity index 87%
rename from Octopi.Tests/Http/ResponseTests.cs
rename to Octokit.Tests/Http/ResponseTests.cs
index 99f46155..b9ad6a30 100644
--- a/Octopi.Tests/Http/ResponseTests.cs
+++ b/Octokit.Tests/Http/ResponseTests.cs
@@ -1,8 +1,8 @@
using FluentAssertions;
-using Octopi.Http;
+using Octokit.Http;
using Xunit;
-namespace Octopi.Tests.Http
+namespace Octokit.Tests.Http
{
public class ResponseTests
{
diff --git a/Octopi.Tests/Octopi.Tests.csproj b/Octokit.Tests/Octokit.Tests.csproj
similarity index 96%
rename from Octopi.Tests/Octopi.Tests.csproj
rename to Octokit.Tests/Octokit.Tests.csproj
index e09169c7..caf9157e 100644
--- a/Octopi.Tests/Octopi.Tests.csproj
+++ b/Octokit.Tests/Octokit.Tests.csproj
@@ -7,8 +7,8 @@
{149448D4-C2F2-4DF9-86BD-03E3272F093B}
Library
Properties
- Octopi.Tests
- Octopi.Tests
+ Octokit.Tests
+ Octokit.Tests
v4.5
512
@@ -81,9 +81,9 @@
-
+
{08dd4305-7787-4823-a53f-4d0f725a07f3}
- Octopi
+ Octokit
diff --git a/Octopi.Tests/Properties/AssemblyInfo.cs b/Octokit.Tests/Properties/AssemblyInfo.cs
similarity index 93%
rename from Octopi.Tests/Properties/AssemblyInfo.cs
rename to Octokit.Tests/Properties/AssemblyInfo.cs
index fe0c0bcb..a8dfba6e 100644
--- a/Octopi.Tests/Properties/AssemblyInfo.cs
+++ b/Octokit.Tests/Properties/AssemblyInfo.cs
@@ -5,11 +5,11 @@ using System.Runtime.InteropServices;
// set of attributes. Change these attribute values to modify the information
// associated with an assembly.
-[assembly: AssemblyTitle("Octopi.Tests")]
+[assembly: AssemblyTitle("Octokit.Tests")]
[assembly: AssemblyDescription("")]
[assembly: AssemblyConfiguration("")]
[assembly: AssemblyCompany("Microsoft")]
-[assembly: AssemblyProduct("Octopi.Tests")]
+[assembly: AssemblyProduct("Octokit.Tests")]
[assembly: AssemblyCopyright("Copyright © Microsoft 2012")]
[assembly: AssemblyTrademark("")]
[assembly: AssemblyCulture("")]
diff --git a/Octopi.Tests/Queryable/AggregateQueryTests.cs b/Octokit.Tests/Queryable/AggregateQueryTests.cs
similarity index 100%
rename from Octopi.Tests/Queryable/AggregateQueryTests.cs
rename to Octokit.Tests/Queryable/AggregateQueryTests.cs
diff --git a/Octopi.Tests/SimpleJsonSerializerTests.cs b/Octokit.Tests/SimpleJsonSerializerTests.cs
similarity index 95%
rename from Octopi.Tests/SimpleJsonSerializerTests.cs
rename to Octokit.Tests/SimpleJsonSerializerTests.cs
index ef580100..2d370c5b 100644
--- a/Octopi.Tests/SimpleJsonSerializerTests.cs
+++ b/Octokit.Tests/SimpleJsonSerializerTests.cs
@@ -1,8 +1,8 @@
using FluentAssertions;
-using Octopi.Http;
+using Octokit.Http;
using Xunit;
-namespace Octopi.Tests
+namespace Octokit.Tests
{
public class SimpleJsonSerializerTests
{
diff --git a/Octopi.Tests/packages.config b/Octokit.Tests/packages.config
similarity index 100%
rename from Octopi.Tests/packages.config
rename to Octokit.Tests/packages.config
diff --git a/Octopi.msbuild b/Octokit.msbuild
similarity index 59%
rename from Octopi.msbuild
rename to Octokit.msbuild
index f91d7c2b..e16c92ab 100644
--- a/Octopi.msbuild
+++ b/Octokit.msbuild
@@ -6,19 +6,19 @@
-
+
-
+
-
+
-
+
diff --git a/Octopi.ruleset b/Octokit.ruleset
similarity index 100%
rename from Octopi.ruleset
rename to Octokit.ruleset
diff --git a/Octopi.sln b/Octokit.sln
similarity index 87%
rename from Octopi.sln
rename to Octokit.sln
index 7bea8c50..95facd9a 100644
--- a/Octopi.sln
+++ b/Octokit.sln
@@ -1,11 +1,11 @@
Microsoft Visual Studio Solution File, Format Version 12.00
# Visual Studio 2012
-Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Octopi", "Octopi\Octopi.csproj", "{08DD4305-7787-4823-A53F-4D0F725A07F3}"
+Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Octokit", "Octokit\Octokit.csproj", "{08DD4305-7787-4823-A53F-4D0F725A07F3}"
EndProject
-Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Octopi.Tests", "Octopi.Tests\Octopi.Tests.csproj", "{149448D4-C2F2-4DF9-86BD-03E3272F093B}"
+Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Octokit.Tests", "Octokit.Tests\Octokit.Tests.csproj", "{149448D4-C2F2-4DF9-86BD-03E3272F093B}"
EndProject
-Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Octopi.Tests.Integration", "Octopi.Tests.Integration\Octopi.Tests.Integration.csproj", "{01687D54-1D87-4562-A721-C57F1C94052C}"
+Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Octokit.Tests.Integration", "Octokit.Tests.Integration\Octokit.Tests.Integration.csproj", "{01687D54-1D87-4562-A721-C57F1C94052C}"
EndProject
Project("{2150E333-8FDC-42A3-9474-1A3956D46DE8}") = "Build", "Build", "{CEC9D451-6291-4EDF-971A-D398144FBF96}"
ProjectSection(SolutionItems) = preProject
@@ -13,8 +13,8 @@ Project("{2150E333-8FDC-42A3-9474-1A3956D46DE8}") = "Build", "Build", "{CEC9D451
build.cmd = build.cmd
script\cibuild.ps1 = script\cibuild.ps1
CustomDictionary.xml = CustomDictionary.xml
- Octopi.msbuild = Octopi.msbuild
- Octopi.ruleset = Octopi.ruleset
+ Octokit.msbuild = Octokit.msbuild
+ Octokit.ruleset = Octokit.ruleset
EndProjectSection
EndProject
Project("{2150E333-8FDC-42A3-9474-1A3956D46DE8}") = "Meta", "Meta", "{397C742D-291E-46BD-99A5-57BB6902FA7B}"
@@ -24,9 +24,9 @@ Project("{2150E333-8FDC-42A3-9474-1A3956D46DE8}") = "Meta", "Meta", "{397C742D-2
README.md = README.md
EndProjectSection
EndProject
-Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "OctopiRT", "Octopi\OctopiRT.csproj", "{C8BC13B6-3FA3-4716-827D-E7706F976FE1}"
+Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "OctokitRT", "Octokit\OctokitRT.csproj", "{C8BC13B6-3FA3-4716-827D-E7706F976FE1}"
EndProject
-Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Octopi.Reactive", "Octopi.Reactive\Octopi.Reactive.csproj", "{674B69B8-0780-4D54-AE2B-C15821FA51CB}"
+Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Octokit.Reactive", "Octokit.Reactive\Octokit.Reactive.csproj", "{674B69B8-0780-4D54-AE2B-C15821FA51CB}"
EndProject
Global
GlobalSection(SolutionConfigurationPlatforms) = preSolution
diff --git a/Octopi.sln.DotSettings b/Octokit.sln.DotSettings
similarity index 100%
rename from Octopi.sln.DotSettings
rename to Octokit.sln.DotSettings
diff --git a/Octopi/Authentication/AnonymousAuthenticator.cs b/Octokit/Authentication/AnonymousAuthenticator.cs
similarity index 79%
rename from Octopi/Authentication/AnonymousAuthenticator.cs
rename to Octokit/Authentication/AnonymousAuthenticator.cs
index 250cf1fb..261868c4 100644
--- a/Octopi/Authentication/AnonymousAuthenticator.cs
+++ b/Octokit/Authentication/AnonymousAuthenticator.cs
@@ -1,6 +1,6 @@
-using Octopi.Http;
+using Octokit.Http;
-namespace Octopi.Authentication
+namespace Octokit.Authentication
{
class AnonymousAuthenticator : IAuthenticationHandler
{
diff --git a/Octopi/Authentication/Authenticator.cs b/Octokit/Authentication/Authenticator.cs
similarity index 96%
rename from Octopi/Authentication/Authenticator.cs
rename to Octokit/Authentication/Authenticator.cs
index 85e8229e..dc1dcf6a 100644
--- a/Octopi/Authentication/Authenticator.cs
+++ b/Octokit/Authentication/Authenticator.cs
@@ -1,7 +1,7 @@
using System.Collections.Generic;
-using Octopi.Http;
+using Octokit.Http;
-namespace Octopi.Authentication
+namespace Octokit.Authentication
{
class Authenticator
{
diff --git a/Octopi/Authentication/BasicAuthenticator.cs b/Octokit/Authentication/BasicAuthenticator.cs
similarity index 94%
rename from Octopi/Authentication/BasicAuthenticator.cs
rename to Octokit/Authentication/BasicAuthenticator.cs
index ce74a5a1..eb5cd01c 100644
--- a/Octopi/Authentication/BasicAuthenticator.cs
+++ b/Octokit/Authentication/BasicAuthenticator.cs
@@ -2,9 +2,9 @@
using System.Diagnostics;
using System.Globalization;
using System.Text;
-using Octopi.Http;
+using Octokit.Http;
-namespace Octopi.Authentication
+namespace Octokit.Authentication
{
class BasicAuthenticator : IAuthenticationHandler
{
diff --git a/Octopi/Authentication/IAuthenticationHandler.cs b/Octokit/Authentication/IAuthenticationHandler.cs
similarity index 68%
rename from Octopi/Authentication/IAuthenticationHandler.cs
rename to Octokit/Authentication/IAuthenticationHandler.cs
index 523a6a8a..d5fa7c14 100644
--- a/Octopi/Authentication/IAuthenticationHandler.cs
+++ b/Octokit/Authentication/IAuthenticationHandler.cs
@@ -1,6 +1,6 @@
-using Octopi.Http;
+using Octokit.Http;
-namespace Octopi.Authentication
+namespace Octokit.Authentication
{
interface IAuthenticationHandler
{
diff --git a/Octopi/Authentication/TokenAuthenticator.cs b/Octokit/Authentication/TokenAuthenticator.cs
similarity index 94%
rename from Octopi/Authentication/TokenAuthenticator.cs
rename to Octokit/Authentication/TokenAuthenticator.cs
index 3f5cf119..f2449931 100644
--- a/Octopi/Authentication/TokenAuthenticator.cs
+++ b/Octokit/Authentication/TokenAuthenticator.cs
@@ -1,8 +1,8 @@
using System;
using System.Globalization;
-using Octopi.Http;
+using Octokit.Http;
-namespace Octopi.Authentication
+namespace Octokit.Authentication
{
class TokenAuthenticator : IAuthenticationHandler
{
diff --git a/Octopi/AuthenticationException.cs b/Octokit/AuthenticationException.cs
similarity index 98%
rename from Octopi/AuthenticationException.cs
rename to Octokit/AuthenticationException.cs
index 190c6be5..4de141ff 100644
--- a/Octopi/AuthenticationException.cs
+++ b/Octokit/AuthenticationException.cs
@@ -2,7 +2,7 @@
using System.Net;
using System.Runtime.Serialization;
-namespace Octopi
+namespace Octokit
{
#if !NETFX_CORE
[Serializable]
diff --git a/Octopi/AuthenticationType.cs b/Octokit/AuthenticationType.cs
similarity index 82%
rename from Octopi/AuthenticationType.cs
rename to Octokit/AuthenticationType.cs
index cee43e66..10f5424d 100644
--- a/Octopi/AuthenticationType.cs
+++ b/Octokit/AuthenticationType.cs
@@ -1,4 +1,4 @@
-namespace Octopi
+namespace Octokit
{
public enum AuthenticationType
{
diff --git a/Octopi/Clients/ApiClient.cs b/Octokit/Clients/ApiClient.cs
similarity index 85%
rename from Octopi/Clients/ApiClient.cs
rename to Octokit/Clients/ApiClient.cs
index f4dfbf0a..39ba72da 100644
--- a/Octopi/Clients/ApiClient.cs
+++ b/Octokit/Clients/ApiClient.cs
@@ -1,6 +1,6 @@
-using Octopi.Http;
+using Octokit.Http;
-namespace Octopi.Clients
+namespace Octokit.Clients
{
public abstract class ApiClient
{
diff --git a/Octopi/Clients/ApiPagination.cs b/Octokit/Clients/ApiPagination.cs
similarity index 97%
rename from Octopi/Clients/ApiPagination.cs
rename to Octokit/Clients/ApiPagination.cs
index 97108ef7..c3fbfe45 100644
--- a/Octopi/Clients/ApiPagination.cs
+++ b/Octokit/Clients/ApiPagination.cs
@@ -3,7 +3,7 @@ using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Threading.Tasks;
-namespace Octopi.Clients
+namespace Octokit.Clients
{
///
/// Used to paginate through API response results.
diff --git a/Octopi/Clients/AuthorizationsClient.cs b/Octokit/Clients/AuthorizationsClient.cs
similarity index 98%
rename from Octopi/Clients/AuthorizationsClient.cs
rename to Octokit/Clients/AuthorizationsClient.cs
index 4b6bf89e..8f284b6f 100644
--- a/Octopi/Clients/AuthorizationsClient.cs
+++ b/Octokit/Clients/AuthorizationsClient.cs
@@ -1,9 +1,9 @@
using System;
using System.Collections.Generic;
using System.Threading.Tasks;
-using Octopi.Http;
+using Octokit.Http;
-namespace Octopi.Clients
+namespace Octokit.Clients
{
public class AuthorizationsClient : ApiClient, IAuthorizationsClient
{
diff --git a/Octopi/Clients/AutoCompleteClient.cs b/Octokit/Clients/AutoCompleteClient.cs
similarity index 95%
rename from Octopi/Clients/AutoCompleteClient.cs
rename to Octokit/Clients/AutoCompleteClient.cs
index 6c1d9567..e01eefb5 100644
--- a/Octopi/Clients/AutoCompleteClient.cs
+++ b/Octokit/Clients/AutoCompleteClient.cs
@@ -3,9 +3,9 @@ using System.Collections.ObjectModel;
using System.Linq;
using System.Collections.Generic;
using System.Threading.Tasks;
-using Octopi.Http;
+using Octokit.Http;
-namespace Octopi.Clients
+namespace Octokit.Clients
{
///
/// Calls API methods meant to support auto complete.
diff --git a/Octopi/Clients/OrganizationsClient.cs b/Octokit/Clients/OrganizationsClient.cs
similarity index 95%
rename from Octopi/Clients/OrganizationsClient.cs
rename to Octokit/Clients/OrganizationsClient.cs
index 4fa7652a..33a87cbc 100644
--- a/Octopi/Clients/OrganizationsClient.cs
+++ b/Octokit/Clients/OrganizationsClient.cs
@@ -1,9 +1,9 @@
using System;
using System.Collections.Generic;
using System.Threading.Tasks;
-using Octopi.Http;
+using Octokit.Http;
-namespace Octopi.Clients
+namespace Octokit.Clients
{
public class OrganizationsClient : ApiClient, IOrganizationsClient
{
diff --git a/Octopi/Clients/RepositoriesClient.cs b/Octokit/Clients/RepositoriesClient.cs
similarity index 97%
rename from Octopi/Clients/RepositoriesClient.cs
rename to Octokit/Clients/RepositoriesClient.cs
index 6fb1859e..12b1c0bb 100644
--- a/Octopi/Clients/RepositoriesClient.cs
+++ b/Octokit/Clients/RepositoriesClient.cs
@@ -1,9 +1,9 @@
using System;
using System.Collections.Generic;
using System.Threading.Tasks;
-using Octopi.Http;
+using Octokit.Http;
-namespace Octopi.Clients
+namespace Octokit.Clients
{
public class RepositoriesClient : ApiClient, IRepositoriesClient
{
diff --git a/Octopi/Clients/SshKeysClient.cs b/Octokit/Clients/SshKeysClient.cs
similarity index 97%
rename from Octopi/Clients/SshKeysClient.cs
rename to Octokit/Clients/SshKeysClient.cs
index 83469752..b36405a8 100644
--- a/Octopi/Clients/SshKeysClient.cs
+++ b/Octokit/Clients/SshKeysClient.cs
@@ -1,9 +1,9 @@
using System;
using System.Collections.Generic;
using System.Threading.Tasks;
-using Octopi.Http;
+using Octokit.Http;
-namespace Octopi.Clients
+namespace Octokit.Clients
{
public class SshKeysClient : ApiClient, ISshKeysClient
{
diff --git a/Octopi/Clients/UsersClient.cs b/Octokit/Clients/UsersClient.cs
similarity index 97%
rename from Octopi/Clients/UsersClient.cs
rename to Octokit/Clients/UsersClient.cs
index 675304f0..79e21924 100644
--- a/Octopi/Clients/UsersClient.cs
+++ b/Octokit/Clients/UsersClient.cs
@@ -1,8 +1,8 @@
using System;
using System.Threading.Tasks;
-using Octopi.Http;
+using Octokit.Http;
-namespace Octopi.Clients
+namespace Octokit.Clients
{
///
/// Supports the ability to get and update users via the GitHub API v3.
diff --git a/Octopi/GitHubClient.cs b/Octokit/GitHubClient.cs
similarity index 98%
rename from Octopi/GitHubClient.cs
rename to Octokit/GitHubClient.cs
index ad132df3..d11a6a9b 100644
--- a/Octopi/GitHubClient.cs
+++ b/Octokit/GitHubClient.cs
@@ -1,8 +1,8 @@
using System;
-using Octopi.Clients;
-using Octopi.Http;
+using Octokit.Clients;
+using Octokit.Http;
-namespace Octopi
+namespace Octokit
{
///
/// A Client for the GitHub API v3. You can read more about the api here: http://developer.github.com.
diff --git a/Octopi/GitHubModels.cs b/Octokit/GitHubModels.cs
similarity index 99%
rename from Octopi/GitHubModels.cs
rename to Octokit/GitHubModels.cs
index ab4d9685..9e7b81f5 100644
--- a/Octopi/GitHubModels.cs
+++ b/Octokit/GitHubModels.cs
@@ -2,9 +2,9 @@
using System.Diagnostics.CodeAnalysis;
using System.Text;
using System.Threading.Tasks;
-using Octopi.Http;
+using Octokit.Http;
-namespace Octopi
+namespace Octokit
{
///
/// Represents an oauth application.
diff --git a/Octopi/Helpers/CollectionExtensions.cs b/Octokit/Helpers/CollectionExtensions.cs
similarity index 95%
rename from Octopi/Helpers/CollectionExtensions.cs
rename to Octokit/Helpers/CollectionExtensions.cs
index 9c925923..eaf7d585 100644
--- a/Octopi/Helpers/CollectionExtensions.cs
+++ b/Octokit/Helpers/CollectionExtensions.cs
@@ -1,6 +1,6 @@
using System.Collections.Generic;
-namespace Octopi
+namespace Octokit
{
internal static class CollectionExtensions
{
diff --git a/Octopi/Helpers/Ensure.cs b/Octokit/Helpers/Ensure.cs
similarity index 98%
rename from Octopi/Helpers/Ensure.cs
rename to Octokit/Helpers/Ensure.cs
index acb9667d..9f7cafb7 100644
--- a/Octopi/Helpers/Ensure.cs
+++ b/Octokit/Helpers/Ensure.cs
@@ -1,6 +1,6 @@
using System;
-namespace Octopi
+namespace Octokit
{
///
/// Ensure input parameters
diff --git a/Octopi/Helpers/StringExtensions.cs b/Octokit/Helpers/StringExtensions.cs
similarity index 99%
rename from Octopi/Helpers/StringExtensions.cs
rename to Octokit/Helpers/StringExtensions.cs
index f9a0cb3f..0082a9e1 100644
--- a/Octopi/Helpers/StringExtensions.cs
+++ b/Octokit/Helpers/StringExtensions.cs
@@ -3,7 +3,7 @@ using System.Collections.Generic;
using System.Diagnostics.CodeAnalysis;
using System.Globalization;
-namespace Octopi
+namespace Octokit
{
internal static class StringExtensions
{
diff --git a/Octopi/Http/ApiConnection.cs b/Octokit/Http/ApiConnection.cs
similarity index 97%
rename from Octopi/Http/ApiConnection.cs
rename to Octokit/Http/ApiConnection.cs
index ede915ff..1042b508 100644
--- a/Octopi/Http/ApiConnection.cs
+++ b/Octokit/Http/ApiConnection.cs
@@ -1,9 +1,9 @@
using System;
using System.Collections.Generic;
using System.Threading.Tasks;
-using Octopi.Clients;
+using Octokit.Clients;
-namespace Octopi.Http
+namespace Octokit.Http
{
public class ApiConnection : IApiConnection
{
diff --git a/Octopi/Http/ApiInfo.cs b/Octokit/Http/ApiInfo.cs
similarity index 98%
rename from Octopi/Http/ApiInfo.cs
rename to Octokit/Http/ApiInfo.cs
index 853bdd0d..ab0f065c 100644
--- a/Octopi/Http/ApiInfo.cs
+++ b/Octokit/Http/ApiInfo.cs
@@ -2,7 +2,7 @@
using System.Collections.Generic;
using System.Collections.ObjectModel;
-namespace Octopi.Http
+namespace Octokit.Http
{
///
/// Extra information returned as part of each api response.
diff --git a/Octopi/Http/ApiInfoExtensions.cs b/Octokit/Http/ApiInfoExtensions.cs
similarity index 97%
rename from Octopi/Http/ApiInfoExtensions.cs
rename to Octokit/Http/ApiInfoExtensions.cs
index 3004fb85..5a5c2732 100644
--- a/Octopi/Http/ApiInfoExtensions.cs
+++ b/Octokit/Http/ApiInfoExtensions.cs
@@ -1,6 +1,6 @@
using System;
-namespace Octopi.Http
+namespace Octokit.Http
{
public static class ApiInfoExtensions
{
diff --git a/Octopi/Http/ApiInfoParser.cs b/Octokit/Http/ApiInfoParser.cs
similarity index 99%
rename from Octopi/Http/ApiInfoParser.cs
rename to Octokit/Http/ApiInfoParser.cs
index 8ba22813..c457fe19 100644
--- a/Octopi/Http/ApiInfoParser.cs
+++ b/Octokit/Http/ApiInfoParser.cs
@@ -4,7 +4,7 @@ using System.Globalization;
using System.Linq;
using System.Text.RegularExpressions;
-namespace Octopi.Http
+namespace Octokit.Http
{
public class ApiInfoParser
{
diff --git a/Octopi/Http/ApiResponse.cs b/Octokit/Http/ApiResponse.cs
similarity index 95%
rename from Octopi/Http/ApiResponse.cs
rename to Octokit/Http/ApiResponse.cs
index 6d8f5e19..32927dc0 100644
--- a/Octopi/Http/ApiResponse.cs
+++ b/Octokit/Http/ApiResponse.cs
@@ -1,7 +1,7 @@
using System;
using System.Collections.Generic;
-namespace Octopi.Http
+namespace Octokit.Http
{
public class ApiResponse : IResponse
{
diff --git a/Octopi/Http/Connection.cs b/Octokit/Http/Connection.cs
similarity index 98%
rename from Octopi/Http/Connection.cs
rename to Octokit/Http/Connection.cs
index eac1126b..f45d4d11 100644
--- a/Octopi/Http/Connection.cs
+++ b/Octokit/Http/Connection.cs
@@ -2,9 +2,9 @@
using System.Globalization;
using System.Net.Http;
using System.Threading.Tasks;
-using Octopi.Authentication;
+using Octokit.Authentication;
-namespace Octopi.Http
+namespace Octokit.Http
{
public class Connection : IConnection
{
diff --git a/Octopi/Http/Credentials.cs b/Octokit/Http/Credentials.cs
similarity index 98%
rename from Octopi/Http/Credentials.cs
rename to Octokit/Http/Credentials.cs
index 1bb07286..d0339fc2 100644
--- a/Octopi/Http/Credentials.cs
+++ b/Octokit/Http/Credentials.cs
@@ -1,6 +1,6 @@
using System.Diagnostics.CodeAnalysis;
-namespace Octopi.Http
+namespace Octokit.Http
{
public class Credentials
{
diff --git a/Octopi/Http/CredentialsExtensions.cs b/Octokit/Http/CredentialsExtensions.cs
similarity index 90%
rename from Octopi/Http/CredentialsExtensions.cs
rename to Octokit/Http/CredentialsExtensions.cs
index 8bf72d16..b5095492 100644
--- a/Octopi/Http/CredentialsExtensions.cs
+++ b/Octokit/Http/CredentialsExtensions.cs
@@ -1,4 +1,4 @@
-namespace Octopi.Http
+namespace Octokit.Http
{
public static class CredentialsExtensions
{
diff --git a/Octopi/Http/HttpClientAdapter.cs b/Octokit/Http/HttpClientAdapter.cs
similarity index 99%
rename from Octopi/Http/HttpClientAdapter.cs
rename to Octokit/Http/HttpClientAdapter.cs
index 7f7f35ff..accdc921 100644
--- a/Octopi/Http/HttpClientAdapter.cs
+++ b/Octokit/Http/HttpClientAdapter.cs
@@ -5,7 +5,7 @@ using System.Net.Http;
using System.Text;
using System.Threading.Tasks;
-namespace Octopi.Http
+namespace Octokit.Http
{
public class HttpClientAdapter : IHttpClient
{
diff --git a/Octopi/Http/HttpVerb.cs b/Octokit/Http/HttpVerb.cs
similarity index 91%
rename from Octopi/Http/HttpVerb.cs
rename to Octokit/Http/HttpVerb.cs
index 6ac182a6..5b4cdeea 100644
--- a/Octopi/Http/HttpVerb.cs
+++ b/Octokit/Http/HttpVerb.cs
@@ -1,6 +1,6 @@
using System.Net.Http;
-namespace Octopi.Http
+namespace Octokit.Http
{
public static class HttpVerb
{
diff --git a/Octopi/Http/IApiConnection.cs b/Octokit/Http/IApiConnection.cs
similarity index 97%
rename from Octopi/Http/IApiConnection.cs
rename to Octokit/Http/IApiConnection.cs
index b0523ef0..80e312ef 100644
--- a/Octopi/Http/IApiConnection.cs
+++ b/Octokit/Http/IApiConnection.cs
@@ -3,7 +3,7 @@ using System.Collections.Generic;
using System.Diagnostics.CodeAnalysis;
using System.Threading.Tasks;
-namespace Octopi.Http
+namespace Octokit.Http
{
///
/// Wraps an IConnection and provides useful methods for an endpoint.
diff --git a/Octopi/Http/IConnection.cs b/Octokit/Http/IConnection.cs
similarity index 96%
rename from Octopi/Http/IConnection.cs
rename to Octokit/Http/IConnection.cs
index 296f80a9..c82e8e7c 100644
--- a/Octopi/Http/IConnection.cs
+++ b/Octokit/Http/IConnection.cs
@@ -2,7 +2,7 @@
using System.Diagnostics.CodeAnalysis;
using System.Threading.Tasks;
-namespace Octopi.Http
+namespace Octokit.Http
{
public interface IConnection
{
diff --git a/Octopi/Http/ICredentialStore.cs b/Octokit/Http/ICredentialStore.cs
similarity index 92%
rename from Octopi/Http/ICredentialStore.cs
rename to Octokit/Http/ICredentialStore.cs
index fb2bd756..3ce7ac80 100644
--- a/Octopi/Http/ICredentialStore.cs
+++ b/Octokit/Http/ICredentialStore.cs
@@ -1,6 +1,6 @@
using System.Diagnostics.CodeAnalysis;
-namespace Octopi.Http
+namespace Octokit.Http
{
public interface ICredentialStore
{
diff --git a/Octopi/Http/IHttpClient.cs b/Octokit/Http/IHttpClient.cs
similarity index 97%
rename from Octopi/Http/IHttpClient.cs
rename to Octokit/Http/IHttpClient.cs
index 95ca4e28..28257213 100644
--- a/Octopi/Http/IHttpClient.cs
+++ b/Octokit/Http/IHttpClient.cs
@@ -1,6 +1,6 @@
using System.Threading.Tasks;
-namespace Octopi.Http
+namespace Octokit.Http
{
///
/// Generic Http client. Useful for those who want to swap out System.Net.HttpClient with something else.
diff --git a/Octopi/Http/IJsonSerializer.cs b/Octokit/Http/IJsonSerializer.cs
similarity index 83%
rename from Octopi/Http/IJsonSerializer.cs
rename to Octokit/Http/IJsonSerializer.cs
index 35ba9159..3f65e15e 100644
--- a/Octopi/Http/IJsonSerializer.cs
+++ b/Octokit/Http/IJsonSerializer.cs
@@ -1,4 +1,4 @@
-namespace Octopi.Http
+namespace Octokit.Http
{
public interface IJsonSerializer
{
diff --git a/Octopi/Http/IRequest.cs b/Octokit/Http/IRequest.cs
similarity index 93%
rename from Octopi/Http/IRequest.cs
rename to Octokit/Http/IRequest.cs
index 72ee8e5f..f7a3bc06 100644
--- a/Octopi/Http/IRequest.cs
+++ b/Octokit/Http/IRequest.cs
@@ -2,7 +2,7 @@
using System.Collections.Generic;
using System.Net.Http;
-namespace Octopi.Http
+namespace Octokit.Http
{
public interface IRequest
{
diff --git a/Octopi/Http/IResponse.cs b/Octokit/Http/IResponse.cs
similarity index 92%
rename from Octopi/Http/IResponse.cs
rename to Octokit/Http/IResponse.cs
index c0514b06..16723f3a 100644
--- a/Octopi/Http/IResponse.cs
+++ b/Octokit/Http/IResponse.cs
@@ -1,7 +1,7 @@
using System;
using System.Collections.Generic;
-namespace Octopi.Http
+namespace Octokit.Http
{
public interface IResponse
{
diff --git a/Octopi/Http/InMemoryCredentialStore.cs b/Octokit/Http/InMemoryCredentialStore.cs
similarity index 95%
rename from Octopi/Http/InMemoryCredentialStore.cs
rename to Octokit/Http/InMemoryCredentialStore.cs
index 818412f9..78a433c5 100644
--- a/Octopi/Http/InMemoryCredentialStore.cs
+++ b/Octokit/Http/InMemoryCredentialStore.cs
@@ -1,6 +1,6 @@
using System.Threading.Tasks;
-namespace Octopi.Http
+namespace Octokit.Http
{
public class InMemoryCredentialStore : ICredentialStore
{
diff --git a/Octopi/Http/JsonHttpPipeline.cs b/Octokit/Http/JsonHttpPipeline.cs
similarity index 98%
rename from Octopi/Http/JsonHttpPipeline.cs
rename to Octokit/Http/JsonHttpPipeline.cs
index a859ff1b..75f956c9 100644
--- a/Octopi/Http/JsonHttpPipeline.cs
+++ b/Octokit/Http/JsonHttpPipeline.cs
@@ -1,6 +1,6 @@
using System.Net.Http;
-namespace Octopi.Http
+namespace Octokit.Http
{
///
/// Responsible for serializing the request and response as JSON and
diff --git a/Octopi/Http/ReadOnlyPagedCollection.cs b/Octokit/Http/ReadOnlyPagedCollection.cs
similarity index 97%
rename from Octopi/Http/ReadOnlyPagedCollection.cs
rename to Octokit/Http/ReadOnlyPagedCollection.cs
index e59e87db..efa8a152 100644
--- a/Octopi/Http/ReadOnlyPagedCollection.cs
+++ b/Octokit/Http/ReadOnlyPagedCollection.cs
@@ -2,7 +2,7 @@
using System.Collections.ObjectModel;
using System.Threading.Tasks;
-namespace Octopi.Http
+namespace Octokit.Http
{
public class ReadOnlyPagedCollection : ReadOnlyCollection, IReadOnlyPagedCollection
{
diff --git a/Octopi/Http/Request.cs b/Octokit/Http/Request.cs
similarity index 96%
rename from Octopi/Http/Request.cs
rename to Octokit/Http/Request.cs
index 8a15ea63..4573c7a5 100644
--- a/Octopi/Http/Request.cs
+++ b/Octokit/Http/Request.cs
@@ -2,7 +2,7 @@
using System.Collections.Generic;
using System.Net.Http;
-namespace Octopi.Http
+namespace Octokit.Http
{
public class Request : IRequest
{
diff --git a/Octopi/Http/SimpleJsonSerializer.cs b/Octokit/Http/SimpleJsonSerializer.cs
similarity index 96%
rename from Octopi/Http/SimpleJsonSerializer.cs
rename to Octokit/Http/SimpleJsonSerializer.cs
index b522ee6a..c69a008c 100644
--- a/Octopi/Http/SimpleJsonSerializer.cs
+++ b/Octokit/Http/SimpleJsonSerializer.cs
@@ -1,4 +1,4 @@
-namespace Octopi.Http
+namespace Octokit.Http
{
public class SimpleJsonSerializer : IJsonSerializer
{
diff --git a/Octopi/IApiPagination.cs b/Octokit/IApiPagination.cs
similarity index 93%
rename from Octopi/IApiPagination.cs
rename to Octokit/IApiPagination.cs
index 1c53a1fa..a6aae0e7 100644
--- a/Octopi/IApiPagination.cs
+++ b/Octokit/IApiPagination.cs
@@ -2,7 +2,7 @@
using System.Collections.Generic;
using System.Threading.Tasks;
-namespace Octopi
+namespace Octokit
{
public interface IApiPagination
{
diff --git a/Octopi/IAuthorizationsClient.cs b/Octokit/IAuthorizationsClient.cs
similarity index 97%
rename from Octopi/IAuthorizationsClient.cs
rename to Octokit/IAuthorizationsClient.cs
index 3f65e4a5..479dfce3 100644
--- a/Octopi/IAuthorizationsClient.cs
+++ b/Octokit/IAuthorizationsClient.cs
@@ -2,7 +2,7 @@
using System.Diagnostics.CodeAnalysis;
using System.Threading.Tasks;
-namespace Octopi
+namespace Octokit
{
public interface IAuthorizationsClient
{
diff --git a/Octopi/IAutoCompleteClient.cs b/Octokit/IAutoCompleteClient.cs
similarity index 95%
rename from Octopi/IAutoCompleteClient.cs
rename to Octokit/IAutoCompleteClient.cs
index 1c00a065..0e26c259 100644
--- a/Octopi/IAutoCompleteClient.cs
+++ b/Octokit/IAutoCompleteClient.cs
@@ -3,7 +3,7 @@ using System.Collections.Generic;
using System.Diagnostics.CodeAnalysis;
using System.Threading.Tasks;
-namespace Octopi
+namespace Octokit
{
public interface IAutoCompleteClient
{
diff --git a/Octopi/IGitHubClient.cs b/Octokit/IGitHubClient.cs
similarity index 90%
rename from Octopi/IGitHubClient.cs
rename to Octokit/IGitHubClient.cs
index c2032be3..a497fbc0 100644
--- a/Octopi/IGitHubClient.cs
+++ b/Octokit/IGitHubClient.cs
@@ -1,6 +1,6 @@
-using Octopi.Http;
+using Octokit.Http;
-namespace Octopi
+namespace Octokit
{
public interface IGitHubClient
{
diff --git a/Octopi/IOrganizationsClient.cs b/Octokit/IOrganizationsClient.cs
similarity index 98%
rename from Octopi/IOrganizationsClient.cs
rename to Octokit/IOrganizationsClient.cs
index f74634b0..dd20d41f 100644
--- a/Octopi/IOrganizationsClient.cs
+++ b/Octokit/IOrganizationsClient.cs
@@ -2,7 +2,7 @@
using System.Diagnostics.CodeAnalysis;
using System.Threading.Tasks;
-namespace Octopi
+namespace Octokit
{
public interface IOrganizationsClient
{
diff --git a/Octopi/IReadOnlyPagedCollection.cs b/Octokit/IReadOnlyPagedCollection.cs
similarity index 97%
rename from Octopi/IReadOnlyPagedCollection.cs
rename to Octokit/IReadOnlyPagedCollection.cs
index ffef8a60..f1a217d7 100644
--- a/Octopi/IReadOnlyPagedCollection.cs
+++ b/Octokit/IReadOnlyPagedCollection.cs
@@ -2,7 +2,7 @@
using System.Diagnostics.CodeAnalysis;
using System.Threading.Tasks;
-namespace Octopi
+namespace Octokit
{
///
/// Reflects a collection of datat returned from an API that can be paged.
diff --git a/Octopi/IRepositoriesClient.cs b/Octokit/IRepositoriesClient.cs
similarity index 99%
rename from Octopi/IRepositoriesClient.cs
rename to Octokit/IRepositoriesClient.cs
index a048e653..b417028b 100644
--- a/Octopi/IRepositoriesClient.cs
+++ b/Octokit/IRepositoriesClient.cs
@@ -2,7 +2,7 @@ using System.Collections.Generic;
using System.Diagnostics.CodeAnalysis;
using System.Threading.Tasks;
-namespace Octopi
+namespace Octokit
{
public interface IRepositoriesClient
{
diff --git a/Octopi/ISshKeysClient.cs b/Octokit/ISshKeysClient.cs
similarity index 99%
rename from Octopi/ISshKeysClient.cs
rename to Octokit/ISshKeysClient.cs
index 88c86687..567e29f4 100644
--- a/Octopi/ISshKeysClient.cs
+++ b/Octokit/ISshKeysClient.cs
@@ -2,7 +2,7 @@
using System.Diagnostics.CodeAnalysis;
using System.Threading.Tasks;
-namespace Octopi
+namespace Octokit
{
public interface ISshKeysClient
{
diff --git a/Octopi/IUsersClient.cs b/Octokit/IUsersClient.cs
similarity index 98%
rename from Octopi/IUsersClient.cs
rename to Octokit/IUsersClient.cs
index 0b3b3880..95617f5e 100644
--- a/Octopi/IUsersClient.cs
+++ b/Octokit/IUsersClient.cs
@@ -2,7 +2,7 @@
using System.Diagnostics.CodeAnalysis;
using System.Threading.Tasks;
-namespace Octopi
+namespace Octokit
{
public interface IUsersClient
{
diff --git a/Octopi/Octopi.csproj b/Octokit/Octokit.csproj
similarity index 96%
rename from Octopi/Octopi.csproj
rename to Octokit/Octokit.csproj
index 8c27af53..37a8a39b 100644
--- a/Octopi/Octopi.csproj
+++ b/Octokit/Octokit.csproj
@@ -7,8 +7,8 @@
{08DD4305-7787-4823-A53F-4D0F725A07F3}
Library
Properties
- Octopi
- Octopi
+ Octokit
+ Octokit
v4.5
512
@@ -21,7 +21,8 @@
prompt
4
true
- ..\Octopi.ruleset
+ ..\Octokit.ruleset
+ true
pdbonly
diff --git a/Octopi/OctopiRT.csproj b/Octokit/OctokitRT.csproj
similarity index 98%
rename from Octopi/OctopiRT.csproj
rename to Octokit/OctokitRT.csproj
index 5482b8d8..03f880a4 100644
--- a/Octopi/OctopiRT.csproj
+++ b/Octokit/OctokitRT.csproj
@@ -9,8 +9,8 @@
{C8BC13B6-3FA3-4716-827D-E7706F976FE1}
Library
Properties
- Octopi
- OctopiRT
+ Octokit
+ OctokitRT
v4.5
512
@@ -22,6 +22,7 @@
DEBUG;TRACE;NETFX_CORE;CODE_ANALYSIS;SIMPLE_JSON_OBJARRAYINTERNAL;SIMPLE_JSON_INTERNAL
prompt
4
+ true
pdbonly
diff --git a/Octopi/Properties/AssemblyInfo.cs b/Octokit/Properties/AssemblyInfo.cs
similarity index 92%
rename from Octopi/Properties/AssemblyInfo.cs
rename to Octokit/Properties/AssemblyInfo.cs
index b8486196..bf3551bc 100644
--- a/Octopi/Properties/AssemblyInfo.cs
+++ b/Octokit/Properties/AssemblyInfo.cs
@@ -6,15 +6,15 @@ using System.Runtime.InteropServices;
// set of attributes. Change these attribute values to modify the information
// associated with an assembly.
-[assembly: AssemblyTitle("Octopi")]
+[assembly: AssemblyTitle("Octokit")]
[assembly: AssemblyDescription("A .NET client library for the GitHub API")]
[assembly: AssemblyConfiguration("")]
[assembly: AssemblyCompany("Microsoft")]
-[assembly: AssemblyProduct("Octopi")]
+[assembly: AssemblyProduct("Octokit")]
[assembly: AssemblyCopyright("Copyright © Microsoft 2012")]
[assembly: AssemblyTrademark("")]
[assembly: AssemblyCulture("")]
-[assembly: InternalsVisibleTo("Octopi.Tests")]
+[assembly: InternalsVisibleTo("Octokit.Tests")]
// Setting ComVisible to false makes the types in this assembly not visible
// to COM components. If you need to access a type in this assembly from
diff --git a/Octopi/SimpleJson.cs b/Octokit/SimpleJson.cs
similarity index 99%
rename from Octopi/SimpleJson.cs
rename to Octokit/SimpleJson.cs
index a583a48b..84d9a7dd 100644
--- a/Octopi/SimpleJson.cs
+++ b/Octokit/SimpleJson.cs
@@ -57,7 +57,7 @@ using System.Reflection;
using System.Runtime.CompilerServices;
using System.Runtime.Serialization;
using System.Text;
-using Octopi.Reflection;
+using Octokit.Reflection;
#if !SIMPLE_JSON_NO_LINQ_EXPRESSION
#endif
@@ -69,7 +69,7 @@ using System.Dynamic;
// ReSharper disable RedundantExplicitArrayCreation
// ReSharper disable SuggestUseVarKeywordEvident
-namespace Octopi
+namespace Octokit
{
///
/// Represents the json array.
@@ -486,7 +486,7 @@ namespace Octopi
}
}
-namespace Octopi
+namespace Octokit
{
///
/// This class encodes and decodes JSON strings.
diff --git a/Octopi/packages.config b/Octokit/packages.config
similarity index 100%
rename from Octopi/packages.config
rename to Octokit/packages.config
diff --git a/Octopi.Tests/Nocto.Tests.csproj.DotSettings b/Octopi.Tests/Nocto.Tests.csproj.DotSettings
deleted file mode 100644
index 7afcb2dd..00000000
--- a/Octopi.Tests/Nocto.Tests.csproj.DotSettings
+++ /dev/null
@@ -1,3 +0,0 @@
-
- True
- True
\ No newline at end of file
diff --git a/Octopi.Tests/Octopi.Tests.csproj.DotSettings b/Octopi.Tests/Octopi.Tests.csproj.DotSettings
deleted file mode 100644
index 7afcb2dd..00000000
--- a/Octopi.Tests/Octopi.Tests.csproj.DotSettings
+++ /dev/null
@@ -1,3 +0,0 @@
-
- True
- True
\ No newline at end of file
diff --git a/README.md b/README.md
index 0027c73c..b9d1a761 100644
--- a/README.md
+++ b/README.md
@@ -1,6 +1,6 @@
-# Octopi - GitHub API Client Library for .NET
+# Octokit - GitHub API Client Library for .NET
-Octopi is a client library targeting .NET 4.0 and above that provides an easy
+Octokit is a client library targeting .NET 4.0 and above that provides an easy
way to interact with the [GitHub API](http://developer.github.com/v3/).
## Usage examples
@@ -15,15 +15,15 @@ Console.WriteLine(user.Followers + " folks love the half ogre!");
## Getting Started
-Octopi is available on NuGet.
+Octokit is available on NuGet.
```
-Install-Package Octopi
+Install-Package Octokit
```
## Build
-Octopi is a single assembly designed to be easy to deploy anywhere. If you prefer
+Octokit is a single assembly designed to be easy to deploy anywhere. If you prefer
to compile it yourself, you’ll need:
* Visual Studio 2012
@@ -33,15 +33,15 @@ To clone it locally click the "Clone in Windows" button above or run the
following git commands.
```
-git clone git@github.com:github/Octopi.git
-cd Octopi
+git clone git@github.com:github/Octokit.net.git Octokit
+cd Octokit
.\build.cmd
```
## Problems?
-Octopi is 100% certified to be bug free. If you find an issue with our
-certification, please visit the [issue tracker](https://github.com/github/Octopi/issues)
+Octokit is 100% certified to be bug free. If you find an issue with our
+certification, please visit the [issue tracker](https://github.com/github/Octokit/issues)
and report the issue.
Please be kind and search to see if the issue is already logged before creating
@@ -59,11 +59,11 @@ problem.
## Contribute
-Visit the [Contributor Guidelines](https://github.com/github/Octopi/blob/master/CONTRIBUTING.md)
+Visit the [Contributor Guidelines](https://github.com/github/Octokit/blob/master/CONTRIBUTING.md)
for more details.
## Copyright and License
Copyright 2013 GitHub, Inc.
-Licensed under the [MIT License](https://github.com/github/Octopi/blob/master/LICENSE.txt)
+Licensed under the [MIT License](https://github.com/github/Octokit/blob/master/LICENSE.txt)
diff --git a/script/cibuild.ps1 b/script/cibuild.ps1
index 5101eff4..15b50815 100644
--- a/script/cibuild.ps1
+++ b/script/cibuild.ps1
@@ -1,6 +1,6 @@
<#
.SYNOPSIS
- Builds and tests Octopi
+ Builds and tests Octokit
.DESCRIPTION
Janky runs this script after checking out a revision and cleaning its
working tree.
@@ -70,7 +70,7 @@ if ($Clean) {
Run-Command -Quiet -Fatal { git clean -xdf }
}
-Write-Output "Building Octopi..."
+Write-Output "Building Octokit..."
Write-Output ""
$output = .\Build-Solution.ps1 Build Release -MSBuildVerbosity quiet 2>&1
if ($LastExitCode -ne 0) {
@@ -101,8 +101,8 @@ function Run-XUnit([string]$project, [int]$timeoutDuration) {
$exitCode = 0
-Write-Output "Running Octopi.Tests..."
-$result = Run-XUnit Octopi.Tests 120
+Write-Output "Running Octokit.Tests..."
+$result = Run-XUnit Octokit.Tests 120
if ($result.ExitCode -eq 0) {
# Print out the test result summary.
Write-Output $result.Output[-1]
@@ -112,8 +112,8 @@ if ($result.ExitCode -eq 0) {
}
Write-Output ""
-Write-Output "Running Octopi.Tests.Integration..."
-$result = Run-XUnit Octopi.Tests.Integration 180
+Write-Output "Running Octokit.Tests.Integration..."
+$result = Run-XUnit Octokit.Tests.Integration 180
if ($result.ExitCode -eq 0) {
# Print out the test result summary.
Write-Output $result.Output[-1]
diff --git a/Octopi.Tests.Integration/RepositoriesClientTests.cs b/Octokit.Tests.Integration/RepositoriesClientTests.cs
similarity index 89%
rename from Octopi.Tests.Integration/RepositoriesClientTests.cs
rename to Octokit.Tests.Integration/RepositoriesClientTests.cs
index 72aa821b..3e926b13 100644
--- a/Octopi.Tests.Integration/RepositoriesClientTests.cs
+++ b/Octokit.Tests.Integration/RepositoriesClientTests.cs
@@ -1,9 +1,9 @@
using System.Threading.Tasks;
using FluentAssertions;
-using Octopi.Http;
+using Octokit.Http;
using Xunit;
-namespace Octopi.Tests.Integration
+namespace Octokit.Tests.Integration
{
public class RepositoriesClientTests
{
@@ -42,14 +42,14 @@ namespace Octopi.Tests.Integration
public class TheGetReadmeMethod
{
[Fact]
- public async Task ReturnsReadmeForOctopi()
+ public async Task ReturnsReadmeForOctokit()
{
var github = new GitHubClient
{
Credentials = new Credentials("xapitestaccountx", "octocat11")
};
// TODO: Change this to request github/octopi once we make this OSS.
var readme = await github.Repository.GetReadme("haacked", "seegit");
readme.Name.Should().Be("README.md");
var readMeHtml = await readme.GetHtmlContent();
@@ -42,14 +42,14 @@ namespace Octopi.Tests.Integration
Credentials = new Credentials("xapitestaccountx", "octocat11")
};
- // TODO: Change this to request github/octopi once we make this OSS.
+ // TODO: Change this to request github/Octokit.net once we make this OSS.
var readme = await github.Repository.GetReadme("haacked", "seegit");
readme.Name.Should().Be("README.md");